Welcome to xHydro's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :hidden:

   readme
   installation
   notebooks/index
   notebooks/use_case
   planification
   contributing
   releasing
   authors
   changelog

.. toctree::
   :maxdepth: 1
   :caption: All Modules

   apidoc/modules

Useful links
------------
- `GitHub Repository <https://github.com/hydrologie/xhydro>`_
- `PyPI <https://pypi.org/project/xhydro/>`_
- `Conda-Forge <https://anaconda.org/conda-forge/xhydro>`_

.. Indices and tables
.. ==================
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
